@@ -1,9 +1,9 @@
 package CPAN::Meta::X;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-10-29'; # DATE
+our $DATE = '2021-04-15'; # DATE
 our $DIST = 'CPAN-Meta-X'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: List of custom (x_*) keys in CPAN distribution metadata being used in the wild
@@ -20,18 +20,23 @@ CPAN::Meta::X - List of custom (x_*) keys in CPAN distribution metadata being us
 
 =head1 VERSION
 
-This document describes version 0.002 of CPAN::Meta::X (from Perl distribution CPAN-Meta-X), released on 2020-10-29.
+This document describes version 0.003 of CPAN::Meta::X (from Perl distribution CPAN-Meta-X), released on 2021-04-15.
 
 =head1 DESCRIPTION
 
 L<The CPAN distribution metadata specification|CPAN::Meta::Spec> allows custom
-keys (those that begin with C<x_> or C<X_> to be added to the metadata. Over
-time, some keys are being used for their specific purposes. This document tries
-to list them.
+keys (those that begin with C<x_> or C<X_>) to be added to the metadata. This
+document tries to catalog the custom keys that are being used by CPAN authors.
 
-This document also lists custom phases and relationships in the
-L<prereqs|CPAN::Meta::Spec/PREREQUISITES> hash that are being used, custom
-keys in L<resources|CPAN::Meta::Spec/resources> hash.
+In addition to custom metadata keys, this document also lists:
+
+=over
+
+=item * custom phases and relationships in the L<prereqs|CPAN::Meta::Spec/PREREQUISITES> hash that are being used by people
+
+=item * custom keys in L<resources|CPAN::Meta::Spec/resources> hash
+
+=back
 
 =head1 LIST OF CUSTOM DISTRIBUTION METADATA KEYS
 
@@ -50,6 +55,8 @@ List of contributors in a release.
 
 Examples:
 
+TBD
+
 References:
 
 =over
@@ -80,8 +87,8 @@ References:
 
 =head2 x_provides_scripts key
 
-List what scripts are being provided in the distribution. The structure is
-modeled after the standard L<provides|CPAN::Meta::Spec/provides> hash.
+List scripts that are being provided in the distribution. The structure is
+modelled after the standard L<provides|CPAN::Meta::Spec/provides> hash.
 
 Examples:
 
@@ -182,7 +189,7 @@ Source repository is at L<https://github.com/perlancar/perl-CPAN-Meta-X>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=CPAN-Meta-X>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-CPAN-Meta-X/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -198,7 +205,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
